@@ -1745,7 +1745,10 @@ make.spikes.to.frate <- function(spikes,
   ## range of spike times else you get an error from hist().  The
   ## default anyway is to do all the spikes within a data file.
 
-
+  ## Note, we need to check for when there are no spikes; this can
+  ## happen when examining a subset of spikes, e.g. a well in a multi-well
+  ## plate that was not working.
+  ## r <- make.spikes.to.frate(list(), beg=100, end=200, clip=TRUE)
   nspikes <- lapply(spikes, length)
   nelectrodes <- length(nspikes)
   
@@ -1776,14 +1779,19 @@ make.spikes.to.frate <- function(spikes,
           PACKAGE="sjemea")
 
   rates <- matrix(z$counts, nrow=nbins, ncol=nelectrodes)
-  ## Now optionally set the upper and lower frame rates if clip is TRUE.
-  if (clip)
-    rates <- pmin(pmax(rates, frate.min), frate.max)
 
+  ## Check if there are any electrodes to process.
+  if (nelectrodes > 0) {
+    ## Now optionally set the upper and lower frame rates if clip is TRUE.
+    if (clip)
+      rates <- pmin(pmax(rates, frate.min), frate.max)
 
-  ## Do the average computation here.
-  ## av.rate == average rate across the array.
-  av.rate <- apply(rates, 1, mean)
+    ## Do the average computation here.
+    ## av.rate == average rate across the array.
+    av.rate <- apply(rates, 1, mean)
+  } else {
+    av.rate <- rep(NA, nbins)
+  }
   ## We can remove the last "time.break" since it does not correspond
   ## to the start of a time frame.
   res <- list(rates=rates,
